import axios from "axios";
import Failure from "core/failure";
import { SearchResults } from "searchResults/domain/searchResultsEntity";
import { SearchResultsDTO } from "./dto/searchResultsDTO";
import { create } from "../domain/searchResultsModel";
import { integratorApiClient } from "core/httpClient";

const searchEndpoint = "/papers/search";

async function search(request: string): Promise<SearchResults> {
  try {
    const response = await integratorApiClient.get<SearchResultsDTO>(
      // searchEndpoint + `?query=` + request + `&page=1`
      "https://run.mocky.io/v3/89c8421d-86b1-4af7-850e-b71def846cfe"
    );
    const dto = response.data;
    return create({ data: dto.data });
  } catch (reason) {
    if (axios.isAxiosError(reason)) {
      throw Failure.fromReason(reason, "failures.services.load");
    }
    throw reason;
  }
}
export { search };
