import classNames from "classnames";
import React, { useState, useEffect } from "react";
import { useSearchViewModel } from "searchResults/controller/searchResultsViewModel";
import { useSearchStoreImplementation } from "searchResults/data/searchStoreImplementation";

const searchDropDownStyle = `
absolute 
top-12 left-0
right-0 
bg-white
w-full
max-h-[200px]
overflow-y-scroll
shadow-md
scrollbar-thin  
scrollbar-thumb-gray-500
scrollbar-track-inherit
scrollbar-thumb-rounded
`



type Props = {
  className?: string;
};

export const SearchView = ({ className }: Props) => {
  const [value, setValue] = useState('');
  const store = useSearchStoreImplementation();
  const {
    search,
    changeSearchRequest,
    searchRequest,
    searchResults,
    isLoading,
    isFailed,
  } = useSearchViewModel(store);

  const changeInputValue = (value: string) => {
    setValue(value);
    changeSearchRequest(value)
  }

  useEffect(() => {
    if (searchRequest !== "") {
      search();
    }
  }, [searchRequest, changeSearchRequest]);

  return (
    <div className={classNames("relative", className)}>
      <input
        type="text"
        className="w-full m-0 p-2 focus:outline-none"
        placeholder="Search..."
        onChange={e => changeInputValue(e.target.value)}
        value={value}
      />
      <div
        className={classNames(
          searchDropDownStyle,
          { "py-2": searchRequest != "" }
        )}
      >
        <ul className="list-none w-full">
          {isLoading && <p className="text-center">Is loading...</p>}
          {isFailed && searchRequest != "" && (
            <p className="text-center">
              Sorry... Something went wrong from our side
            </p>
          )}
          {!isLoading &&
            !isFailed &&
            searchResults != undefined &&
            searchRequest != "" &&
            searchResults.data.map((result) => (
              <li
                className="py-1.5 px-3 hover:bg-blue-100 transition-colors cursor-pointer"
                onClick={() => {
                  if (result.title != undefined) {
                    changeInputValue(result.title)
                  }
                }}
              >
                {result.title}
              </li>
            ))}
        </ul>
      </div>
    </div>
  );
};
